MarkdownDocument class

Constructors

MarkdownDocument(String imagePrefix, [dynamic document])

Properties

hashCode → int
The hash code for this object.
no setterinherited
imagePrefix → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

h1(String value) → MarkdownDocument
h2(String value) → MarkdownDocument
h3(String value) → MarkdownDocument
image(String imagePath, [String? imageText, bool showText = false]) → MarkdownDocument
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
point(String value) → MarkdownDocument
separator() → MarkdownDocument
text(String? value) → MarkdownDocument
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited